@@ -1,7 +1,13 @@
 checkRVersion <- function(quiet=FALSE)
   {
-    page <- scan(file="http://cran.r-project.org/src/base/R-2", what="", quiet=TRUE)
-    matches <- grep("R-[0-9]\\.[0-9]+\\.[0-9]+", page, value=TRUE)
+    page2 <- scan(file="http://cran.r-project.org/src/base/R-2",
+                  what="", quiet=TRUE)
+    page3 <- scan(file="http://cran.r-project.org/src/base/R-3",
+                  what="", quiet=TRUE)
+
+    combined <- c(page2, page3)
+    
+    matches <- grep("R-[0-9]\\.[0-9]+\\.[0-9]+", combined, value=TRUE)
     versionList <- gsub("^.*R-([0-9].[0-9]+.[0-9]+).*$","\\1",matches)
     versionList <- numeric_version(versionList)
     if( max(versionList) > getRversion() )
