@@ -1,6 +1,4 @@
 ## useful function, raises an error if the FLAG expression is FALSE
 assert <- function( FLAG )
-  {
-    .Deprecated(new="stopifnot", package="base")
-    stopifnot(FLAG)
-  }
+    .Defunct(new="stopifnot", package="gtools")
+
